=============================================
``psyclone.psyir.transformations.intrinsics``
=============================================

.. automodule:: psyclone.psyir.transformations.intrinsics

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.psyir.transformations.intrinsics.abs2code_trans
   psyclone.psyir.transformations.intrinsics.dotproduct2code_trans
   psyclone.psyir.transformations.intrinsics.matmul2code_trans
   psyclone.psyir.transformations.intrinsics.max2code_trans
   psyclone.psyir.transformations.intrinsics.min2code_trans
   psyclone.psyir.transformations.intrinsics.minormax2code_trans
   psyclone.psyir.transformations.intrinsics.operator2code_trans
   psyclone.psyir.transformations.intrinsics.sign2code_trans

.. currentmodule:: psyclone.psyir.transformations.intrinsics
